pymus - Audio & Music analysis tools
------------------------------------

A Python library including several tools for automatic music analysis.
Special focus is on algorithms for score-informed analysis of melodies in audio recordings of musical instruments.
